@@ -12,7 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
 
 from os_win.tests.unit import test_base
 from os_win.utils.compute import rdpconsoleutils
